You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by sa...@apache.org on 2005/11/21 04:57:03 UTC

svn commit: r345821 [1/8] - in /webservices/axis2/trunk/c: ./ include/ modules/test/om/src/ modules/util/src/ modules/xml/guththila/ modules/xml/om/src/ modules/xml/om/test/ modules/xml/parser/ modules/xml/parser/guththila/impl/src/ modules/xml/parser/...

Author: samisa
Date: Sun Nov 20 19:53:26 2005
New Revision: 345821

URL: http://svn.apache.org/viewcvs?rev=345821&view=rev
Log:
guththila code improved and guththila_reader changed , libxml2 reader wrapper code added 

Added:
    webservices/axis2/trunk/c/modules/test/om/src/axis.xml
    webservices/axis2/trunk/c/modules/test/om/src/basic.xml
    webservices/axis2/trunk/c/modules/test/om/src/basicupdate.xml
    webservices/axis2/trunk/c/modules/test/om/src/contents.xml
    webservices/axis2/trunk/c/modules/test/om/src/defaultNamespace.xml
    webservices/axis2/trunk/c/modules/test/om/src/evaluate.xml
    webservices/axis2/trunk/c/modules/test/om/src/fibo.xml
    webservices/axis2/trunk/c/modules/test/om/src/id.xml
    webservices/axis2/trunk/c/modules/test/om/src/jaxen24.xml
    webservices/axis2/trunk/c/modules/test/om/src/jaxen3.xml
    webservices/axis2/trunk/c/modules/test/om/src/lang.xml
    webservices/axis2/trunk/c/modules/test/om/src/message.xml
    webservices/axis2/trunk/c/modules/test/om/src/moreover.xml
    webservices/axis2/trunk/c/modules/test/om/src/much_ado.xml
    webservices/axis2/trunk/c/modules/test/om/src/namespaces.xml
    webservices/axis2/trunk/c/modules/test/om/src/nitf.xml
    webservices/axis2/trunk/c/modules/test/om/src/numbers.xml
    webservices/axis2/trunk/c/modules/test/om/src/pi.xml
    webservices/axis2/trunk/c/modules/test/om/src/pi2.xml
    webservices/axis2/trunk/c/modules/test/om/src/simple.xml
    webservices/axis2/trunk/c/modules/test/om/src/spaces.xml
    webservices/axis2/trunk/c/modules/test/om/src/t.xml
    webservices/axis2/trunk/c/modules/test/om/src/testNamespaces.xml
    webservices/axis2/trunk/c/modules/test/om/src/text.xml
    webservices/axis2/trunk/c/modules/test/om/src/underscore.xml
    webservices/axis2/trunk/c/modules/test/om/src/web.xml
    webservices/axis2/trunk/c/modules/test/om/src/web2.xml
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/src/axis2_libxml2_wrapper.c   (with props)
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/test/libxml_test.c   (with props)
Removed:
    webservices/axis2/trunk/c/modules/xml/guththila/
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_stream.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_stream.h
Modified:
    webservices/axis2/trunk/c/configure
    webservices/axis2/trunk/c/configure.ac
    webservices/axis2/trunk/c/include/axis2_om_attribute.h
    webservices/axis2/trunk/c/include/axis2_om_comment.h
    webservices/axis2/trunk/c/include/axis2_om_doctype.h
    webservices/axis2/trunk/c/include/axis2_om_document.h
    webservices/axis2/trunk/c/include/axis2_om_element.h
    webservices/axis2/trunk/c/include/axis2_om_namespace.h
    webservices/axis2/trunk/c/include/axis2_om_node.h
    webservices/axis2/trunk/c/include/axis2_om_output.h
    webservices/axis2/trunk/c/include/axis2_om_processing_instruction.h
    webservices/axis2/trunk/c/include/axis2_om_stax_builder.h
    webservices/axis2/trunk/c/include/axis2_om_text.h
    webservices/axis2/trunk/c/modules/test/om/src/test_om.c
    webservices/axis2/trunk/c/modules/util/src/axis2_string.h
    webservices/axis2/trunk/c/modules/util/src/env.c
    webservices/axis2/trunk/c/modules/util/src/error.c
    webservices/axis2/trunk/c/modules/util/src/linked_list.c
    webservices/axis2/trunk/c/modules/util/src/string.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_attribute.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_comment.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_doctype.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_element.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_node.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_output.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_processing_instruction.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_stax_builder.c
    webservices/axis2/trunk/c/modules/xml/om/src/axis2_om_text.c
    webservices/axis2/trunk/c/modules/xml/om/test/Makefile.am
    webservices/axis2/trunk/c/modules/xml/om/test/Makefile.in
    webservices/axis2/trunk/c/modules/xml/om/test/om_test.c
    webservices/axis2/trunk/c/modules/xml/om/test/om_test.h
    webservices/axis2/trunk/c/modules/xml/parser/axis2_pull_parser.h
    webservices/axis2/trunk/c/modules/xml/parser/axis2_xml_writer.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/Makefile.am
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/Makefile.in
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_allocator.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_allocator.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_array.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_array.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_buffer.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_buffer.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_depth.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_environment.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_environment.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_error.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_error.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_hash.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_hash.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_log.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_log.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_main.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_namespace.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_reader.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_reader.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_stack.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_stack.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_string.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_string.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_token.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_token.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_unicode.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_xml_pull_parser.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_xml_pull_parser.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_xml_stream_writer.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/impl/src/guththila_xml_stream_writer.h
    webservices/axis2/trunk/c/modules/xml/parser/guththila/src/Makefile
    webservices/axis2/trunk/c/modules/xml/parser/guththila/src/axis2_guththila_wrapper.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/src/guththila_xml_writer_wrapper.c
    webservices/axis2/trunk/c/modules/xml/parser/guththila/test/Makefile
    webservices/axis2/trunk/c/modules/xml/parser/guththila/test/Makefile.am
    webservices/axis2/trunk/c/modules/xml/parser/guththila/test/Makefile.in
    webservices/axis2/trunk/c/modules/xml/parser/guththila/test/guththila_test.c
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/src/Makefile
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/src/Makefile.am
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/src/Makefile.in
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/test/Makefile
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/test/Makefile.am
    webservices/axis2/trunk/c/modules/xml/parser/libxml2/test/Makefile.in

Modified: webservices/axis2/trunk/c/configure
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/configure?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/configure (original)
+++ webservices/axis2/trunk/c/configure Sun Nov 20 19:53:26 2005
@@ -22469,7 +22469,7 @@
 PULL_PARSER=$want_parser
 
 
-                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ac_config_files="$ac_config_files Makefile modules/Makefile modules/core/Makefile modules/core/context/Makefile modules/core/context/src/Makefile modules/core/context/test/Makefile modules/core/description/Makefile modules/core/description/src/Makefile modules/core/description/test/Makefile modules/core/engine/Makefile modules/core/engine/src/Makefile modules/core/engine/test/Makefile modules/core/handlers/Makefile modules/core/handlers/src/Makefile modules/xml/Makefile modules/xml/guththila/Makefile modules/xml/guththila/src/Makefile modules/xml/parser/Makefile modules/xml/parser/guththila/Makefile modules/xml/parser/guththila/impl/Makefile modules/xml/parser/guththila/impl/src/Makefile modules/xml/parser/guththila/src/Makefile modules/xml/parser/guththila/test/Makefile modules/xml/parser/libxml2/Makefile modules/xml/parser/libxml2/src/Makefile modules/xml/parser/libxml2/test/Makefile modules/xml/soap/Makefile modules/xml/soap/src/Makefile modules/xml/om/Makefile modules/xml/om/src/Makefile modules/xml/om/test/Makefile modules/common/Makefile modules/common/src/Makefile modules/common/test/Makefile modules/util/Makefile modules/util/src/Makefile modules/util/test/Makefile modules/wsdl/Makefile modules/wsdl/src/Makefile modules/wsdl/test/Makefile modules/test/Makefile modules/test/om/Makefile modules/test/om/src/Makefile modules/test/common/Makefile modules/test/core/Makefile modules/test/core/handlers/Makefile modules/test/util/Makefile modules/test/unit/Makefile"
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ac_config_files="$ac_config_files Makefile modules/Makefile modules/core/Makefile modules/core/context/Makefile modules/core/context/src/Makefile modules/core/context/test/Makefile modules/core/description/Makefile modules/core/description/src/Makefile modules/core/description/test/Makefile modules/core/engine/Makefile modules/core/engine/src/Makefile modules/core/engine/test/Makefile modules/core/handlers/Makefile modules/core/handlers/src/Makefile modules/xml/Makefile modules/xml/parser/Makefile modules/xml/parser/guththila/Makefile modules/xml/parser/guththila/impl/Makefile modules/xml/parser/guththila/impl/src/Makefile modules/xml/parser/guththila/src/Makefile modules/xml/parser/guththila/test/Makefile modules/xml/parser/libxml2/Makefile modules/xml/parser/libxml2/src/Makefile modules/xml/parser/libxml2/test/Makefile modules/xml/soap/Makefile modules/xml/soap/src/Makefile modules/xml/om/Makefile modules/xml/om/src/Makefile modules/xml/om/test/Makefile modules/common/Makefile modules/common/src/Makefile modules/common/test/Makefile modules/util/Makefile modules/util/src/Makefile modules/util/test/Makefile modules/wsdl/Makefile modules/wsdl/src/Makefile modules/wsdl/test/Makefile modules/test/Makefile modules/test/om/Makefile modules/test/om/src/Makefile modules/test/common/Makefile modules/test/core/Makefile modules/test/core/handlers/Makefile modules/test/util/Makefile modules/test/unit/Makefile"
 
 
 cat >confcache <<\_ACEOF
@@ -23078,8 +23078,6 @@
   "modules/core/handlers/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/core/handlers/Makefile" ;;
   "modules/core/handlers/src/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/core/handlers/src/Makefile" ;;
   "modules/xml/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/Makefile" ;;
-  "modules/xml/guththila/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/guththila/Makefile" ;;
-  "modules/xml/guththila/src/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/guththila/src/Makefile" ;;
   "modules/xml/parser/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/parser/Makefile" ;;
   "modules/xml/parser/guththila/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/parser/guththila/Makefile" ;;
   "modules/xml/parser/guththila/impl/Makefile" ) CONFIG_FILES="$CONFIG_FILES modules/xml/parser/guththila/impl/Makefile" ;;

Modified: webservices/axis2/trunk/c/configure.ac
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/configure.ac?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/configure.ac (original)
+++ webservices/axis2/trunk/c/configure.ac Sun Nov 20 19:53:26 2005
@@ -105,8 +105,6 @@
     modules/core/handlers/Makefile \
     modules/core/handlers/src/Makefile \
     modules/xml/Makefile \
-    modules/xml/guththila/Makefile \
-    modules/xml/guththila/src/Makefile \
     modules/xml/parser/Makefile \
     modules/xml/parser/guththila/Makefile \
     modules/xml/parser/guththila/impl/Makefile \

Modified: webservices/axis2/trunk/c/include/axis2_om_attribute.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_attribute.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_attribute.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_attribute.h Sun Nov 20 19:53:26 2005
@@ -21,7 +21,7 @@
 * @file axis2_om_attribute.h
 * @brief om attribute struct represents an xml attribute
 */
-
+#include <axis2_env.h>
 #include <axis2_qname.h>
 #include <axis2_om_namespace.h>
 #include <axis2_om_output.h>
@@ -42,68 +42,100 @@
 
 /**
  *   \brief OM attribute operations struct
- *   Encapsulator struct for axis2_om_attribute
+ *   operations Encapsulator struct for axis2_om_attribute
  */
  AXIS2_DECLARE_DATA   typedef struct axis2_om_attribute_ops
     {
       /**
         * Free an axis2_om_attribute struct
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param om_attribute pointer to attribute struct to be freed
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
+        * @param  om_attribute pointer to attribute struct to be freed
+        * @param  env Environment. MUST NOT be NULL
+        * @return satus of the operation. AXIS2_SUCCESS on success 
+        *         else AXIS2_FAILURE
         */
 
-         axis2_status_t 
-         (AXIS2_CALL *free) (struct axis2_om_attribute *om_attribute,
-                                                    axis2_env_t **env);
+        axis2_status_t 
+        (AXIS2_CALL *free)(struct axis2_om_attribute *om_attribute,
+                           axis2_env_t **env);
 
       /** 
         * Creates and returns a qname struct for this attribute
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param om_attribute pointer to attribute struct for which the qname is to be returned
-        * @return returns qname for given attribute. NULL on error 
+        * @param env Environment. MUST NOT be NULL
+        * @param om_attribute pointer to attribute struct 
+        *        for which the qname is to be returned
+        * @return returns qname for given attribute.NULL on error 
         */
 
-         axis2_qname_t *
-         (AXIS2_CALL *get_qname) (struct axis2_om_attribute *om_attribute,
-                                                         axis2_env_t **env);
+        axis2_qname_t * (AXIS2_CALL *get_qname)
+                                (struct axis2_om_attribute *om_attribute,
+                                axis2_env_t **env);
 
       /**
         * Serialize operation
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_attribute pointer to attribute struct to be serialized
+        * @param env Environment. MUST NOT be NULL,
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
 
-         int 
-         (AXIS2_CALL *serialize) (struct axis2_om_attribute *om_attribute,
-                                                 axis2_env_t **env,
-                                                 axis2_om_output_t *om_output);
-        axis2_char_t* 
-        (AXIS2_CALL *get_localname)(struct axis2_om_attribute *om_attribute,
+        int (AXIS2_CALL *serialize)(struct axis2_om_attribute *om_attribute,
+                                    axis2_env_t **env,
+                                    axis2_om_output_t *om_output);
+       /**  returns the localname of this attribute
+        *@param om_attribute this attribute
+        *@param env environment must not be null
+        *@return localname
+        */
+        axis2_char_t* (AXIS2_CALL *get_localname)(
+                                    struct axis2_om_attribute *om_attribute,
                                     axis2_env_t **env);
-
-        axis2_char_t* 
-        (AXIS2_CALL *get_value)(struct axis2_om_attribute *om_attribute,
-                                axis2_env_t **env);
-
-        axis2_om_namespace_t* 
-        (AXIS2_CALL *get_namespace)(struct axis2_om_attribute *om_attribute,
+       /**
+        * returns value of this attribute 
+        *@param om_attribute
+        *@param env environment must not be null
+        *@return value , null on error
+        */
+        axis2_char_t* (AXIS2_CALL *get_value)
+                                    (struct axis2_om_attribute *om_attribute,
+                                     axis2_env_t **env);
+       /**
+        * returns namespace of this attribute 
+        *@param om_attribute
+        *@param env environment must not be null
+        *@return value , null on error
+        */
+        axis2_om_namespace_t* (AXIS2_CALL *get_namespace)
+                                   (struct axis2_om_attribute *om_attribute,
                                     axis2_env_t **env);
-
-        axis2_status_t 
-        (AXIS2_CALL *set_localname)(struct axis2_om_attribute *om_attribute,
+       /**
+        *@param om_attribute 
+        *@param env environment
+        *@param localname localname for this attribute 
+        *@return status code 
+        */
+        axis2_status_t (AXIS2_CALL *set_localname)
+                                    (struct axis2_om_attribute *om_attribute,
                                     axis2_env_t **env,
                                     const axis2_char_t *localname);
-
-        axis2_status_t 
-        (AXIS2_CALL *set_value)(struct axis2_om_attribute *om_attribute,
+       /**
+        *@param om_attribute 
+        *@param env environment
+        *@param localname localname for this attribute 
+        *@return status code 
+        */
+        
+        axis2_status_t (AXIS2_CALL *set_value)
+                                (struct axis2_om_attribute *om_attribute,
                                 axis2_env_t **env,
                                 const axis2_char_t *value);
-
-        axis2_status_t 
-        (AXIS2_CALL *set_namespace)(struct axis2_om_attribute *om_attribute,
+        /**
+        *@param om_attribute 
+        *@param env environment
+        *@param om_namespace namespace for this attribute 
+        *@return status code on error returns AXIS2_FAILURE ,AXIS2_SUCCESS otherwise
+        */
+        axis2_status_t (AXIS2_CALL *set_namespace)
+                                    (struct axis2_om_attribute *om_attribute,
                                     axis2_env_t **env,
                                     axis2_om_namespace_t *om_namespace);
                                                                                                                                                                                              
@@ -123,21 +155,22 @@
     } axis2_om_attribute_t;
 
   /**
-    * creates an om_attribute structure 
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-    * @param localname The local part of the attribute name. Mandatory, cannot be NULL
-    * @param value normalized attribute value. Mandatory, cannot be NULL
+    * creates an om_attribute structure instance
+    * @param env Environment. MUST NOT be NULL
+    * @param localname localname of the attribute, cannot be a null value
+    * @param value normalized attribute value. cannot be NULL
     * @param ns namespace, if any, of the attribute. Optional, can be NULL
     * @return a pointer to newly created attribute struct 
     */
     AXIS2_DECLARE(axis2_om_attribute_t *)
-     axis2_om_attribute_create (axis2_env_t **env,
-                                const axis2_char_t *localname,
-                                const axis2_char_t *value,
-                                axis2_om_namespace_t *ns);
-
-/******************** Macros *********************************************/
-
+    axis2_om_attribute_create (axis2_env_t **env,
+                               const axis2_char_t *localname,
+                               const axis2_char_t *value,
+                               axis2_om_namespace_t *ns);
+
+/******************** Macros **************************************************/
+    
+    
 /** free given attribute */
 #define AXIS2_OM_ATTRIBUTE_FREE(om_attribute, env) \
         ((om_attribute)->ops->free(om_attribute, env))
@@ -149,26 +182,24 @@
 /** serialize given attribute */
 #define AXIS2_OM_ATTRIBUTE_SERIALIZE(om_attribute, env, om_ouput) \
         ((om_attribute)->ops->serialize(om_attribute, env, om_output))
-        
+/** get namespace of an the attribute */        
 #define AXIS2_OM_ATTRIBUTE_GET_NAMESPACE(om_attribute, env) \
         ((om_attribute)->ops->get_namespace(om_attribute, env))
-
+/** get attribute localname */
 #define AXIS2_OM_ATTRIBUTE_GET_LOCALNAME(om_attribute, env) \
         ((om_attribute)->ops->get_localname(om_attribute, env))
-        
+/** grt value of attribute */        
 #define AXIS2_OM_ATTRIBUTE_GET_VALUE(om_attribute, env) \
         ((om_attribute)->ops->get_value(om_attribute, env))
-               
+/** set namespace for this attribute */               
 #define AXIS2_OM_ATTRIBUTE_SET_NAMESPACE(om_attribute, env,ns) \
         ((om_attribute)->ops->set_namespace(om_attribute, env,ns))
-        
+/** set localname for this attribute */        
 #define AXIS2_OM_ATTRIBUTE_SET_LOCALNAME(om_attribute, env,localname) \
         ((om_attribute)->ops->set_localname(om_attribute, env,localname))
-
+/** set attribue value */
 #define AXIS2_OM_ATTRIBUTE_SET_VALUE(om_attribute, env,value) \
         ((om_attribute)->ops->set_value(om_attribute, env,value))
-                
-                
 
 /** @} */
 
@@ -176,4 +207,4 @@
 }
 #endif
 
-#endif                          /* AXIS2_OM_ATTRIBUTE_H */
+#endif  /* AXIS2_OM_ATTRIBUTE_H */

Modified: webservices/axis2/trunk/c/include/axis2_om_comment.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_comment.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_doctype.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_doctype.h Sun Nov 20 19:53:26 2005
@@ -23,6 +23,7 @@
  */
 
 #include <axis2_om_node.h>
+#include <axis2_om_output.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -46,19 +47,31 @@
     {
       /**
         * free doctype struct
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_doctype pointer to doctype struct to be freed
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
+        * @param env Environment. MUST NOT be NULL,
+        * @return satus of the operation. AXIS2_SUCCESS on success
+        *        else AXIS2_FAILURE
         */
-        axis2_status_t (AXIS2_CALL *free) (struct axis2_om_doctype *om_doctype,
-                                            axis2_env_t **env);
-
-        axis2_char_t* (AXIS2_CALL *get_value)(struct axis2_om_doctype *om_doctype,
-                                              axis2_env_t **env);
-
-        axis2_status_t (AXIS2_CALL *set_value)(struct axis2_om_doctype *om_doctype,
-                                               axis2_env_t **env,
-                                               const axis2_char_t *value);
+        axis2_status_t (AXIS2_CALL *free)(struct axis2_om_doctype *om_doctype,
+                                          axis2_env_t **env);
+       /**
+        * @param om_doctype pointer to a om_doctype struct
+        * @param env environment must not be null       
+        * @return value 
+        */
+        axis2_char_t* (AXIS2_CALL *get_value)
+                                    (struct axis2_om_doctype *om_doctype,
+                                     axis2_env_t **env);
+
+        axis2_status_t (AXIS2_CALL *set_value)
+                                    (struct axis2_om_doctype *om_doctype,
+                                     axis2_env_t **env,
+                                     const axis2_char_t *value);
+        
+        axis2_status_t (AXIS2_CALL *serialize)
+                                    (struct axis2_om_doctype *om_doctype,
+                                     axis2_env_t **env,
+                                     axis2_om_output_t *om_output);
                                                                                                                                       
     } axis2_om_doctype_ops_t;
 
@@ -75,12 +88,12 @@
 
   /**
     * Creates a doctype struct
-    * @param environment Environment. MUST  NOT be NULL, if NULL behaviour is undefined.
+    * @param env Environment. MUST  NOT be NULL,
     * @param parent parent of the new node. Optinal, can be NULL. 
     * @param value doctype value 
-    * @param node This is an out parameter. Mandatory, cannot be NULL.
-    *                       Returns the node corresponding to the doctype created.
-    *                       Node type will be set to AXIS2_OM_DOCTYPE
+    * @param node This is an out parameter.cannot be NULL.
+    *               Returns the node corresponding to the doctype created.
+    *               Node type will be set to AXIS2_OM_DOCTYPE
     * @return pointer to newly created doctype struct 
     */
     AXIS2_DECLARE(axis2_om_doctype_t *)
@@ -90,15 +103,17 @@
                              axis2_om_node_t ** node);
 
 /** free given doctype */    
-#define AXIS2_OM_DOCTYPE_FREE(doctype,env) \
-        ((doctype)->ops->free(doctype,env))
-
-#define AXIS2_OM_DOCTYPE_GET_VALUE(doctype,env) \
-        ((doctype)->ops->get_value(doctype,value))
-
-#define AXIS2_OM_DOCTYPE_SET_VALUE(doctype,env,value) \
-        ((doctype)->ops->set_value(doctype,env,value))
-                       
+#define AXIS2_OM_DOCTYPE_FREE(doctype, env) \
+        ((doctype)->ops->free(doctype, env))
+/** returns the value of doctype */
+#define AXIS2_OM_DOCTYPE_GET_VALUE(doctype, env) \
+        ((doctype)->ops->get_value(doctype, value))
+/** set the doctype value */
+#define AXIS2_OM_DOCTYPE_SET_VALUE(doctype, env, value) \
+        ((doctype)->ops->set_value(doctype, env, value))
+        
+#define AXIS2_OM_DOCTYPE_SERIALIZE(doctype, env, om_output) \
+        ((doctype)->ops->serialize(doctype, env, om_output))
 
 /** @} */
     

Modified: webservices/axis2/trunk/c/include/axis2_om_document.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_document.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_document.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_document.h Sun Nov 20 19:53:26 2005
@@ -54,8 +54,8 @@
 
       /** 
         * Frees document struct
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.        
         * @param document pointer to document struct to be freed
+        * @param env Environment. MUST NOT be NULL    
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
         axis2_status_t (AXIS2_CALL *free) (struct axis2_om_document *document,
@@ -63,8 +63,8 @@
 
       /**
         * Builds the next node if the builder is not finished with input xml stream
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.        
-        * @param document document whose next node is to be built. Mandatory, cannot be NULL
+        * @param document document whose next node is to be built. cannot be NULL
+        * @param env Environment. MUST NOT be NULL.        
         * @return pointer to the next node. NULL on error.
         */
         axis2_om_node_t* (AXIS2_CALL *build_next) (struct axis2_om_document *document,
@@ -72,9 +72,9 @@
 
       /**
         * adds the child node to the document. To the back of the children list.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.        
-        * @param document document to add the child. Mandatory, cannot be NULL.
-        * @param child child node to be added. Mandatory, cannot be NULL.
+        * @param document document to add the child. cannot be NULL.
+        * @param envi Environment. MUST NOT be NULL.        
+        * @param child child node to be added. cannot be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
         axis2_status_t (AXIS2_CALL *add_child)(struct axis2_om_document * document,
@@ -83,22 +83,32 @@
 
       /**
         * Gets the root element of the document.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.        
         * @param document document to return the root of
-        * @return returns a pointer to the root node. If no root present, this method tries to 
-        *             build the root. Returns NULL on error. 
+        * @param env Environment. MUST NOT be NULL.        
+        * @return returns a pointer to the root node. If no root present,
+        *            this method tries to build the root. Returns NULL on error. 
         */
         axis2_om_node_t* (AXIS2_CALL *get_root_element)(struct axis2_om_document *document,
                                                         axis2_env_t **env);
+
+      /**
+        * set the root element of the document.
+        * @param document document to return the root of
+        * @param env Environment. MUST NOT be NULL.        
+        * @return returns status code 
+        *         Returns AXIS2_FAILURE on error. 
+        */        
                                                         
         axis2_status_t (AXIS2_CALL *set_root_element)(struct axis2_om_document *document,
                                                        axis2_env_t **env,
                                                        axis2_om_node_t *om_node);
-        
+       /**
+        * builds till the complete document is built
+        *@param document document struct 
+        *@param env environment cannot be null.
+        */
         axis2_om_node_t* (AXIS2_CALL *build_all)(struct axis2_om_document *document,
                                                 axis2_env_t **env);            
-
-
     } axis2_om_document_ops_t;
 
   /**
@@ -114,7 +124,7 @@
 
   /**
     * creates a document
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+    * @param env Environment. MUST NOT be NULL.
     * @param root pointer to document's root node. Optional, can be NULL
     * @param builder pointer to xml builder 
     * @return pointer to the newly created document.
@@ -139,10 +149,10 @@
 /** gets the root eleemnt of given document */
 #define AXIS2_OM_DOCUMENT_GET_ROOT_ELEMENT(document,env) \
         ((document)->ops->get_root_element(document,env))
-
+/** sets the root node */
 #define AXIS2_OM_DOCUMENT_SET_ROOT_ELEMENT(document,env,om_node) \
         ((document)->ops->set_root_element(document,env,om_node))       
-
+/** build till the root node is complete */
 #define AXIS2_OM_DOCUMENT_BUILD_ALL(document,env) \
         ((document)->ops->build_all(document,env))
 

Modified: webservices/axis2/trunk/c/include/axis2_om_element.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_element.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_element.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_element.h Sun Nov 20 19:53:26 2005
@@ -48,63 +48,52 @@
        /*
         * Find a namespace in the scope of the document.
         * Start to find from the given node and go up the hierarchy.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param node node containing an instance of an OM element. Mandatory, cannot be NULL.
-        * @param uri namespace uri. Mandatory, cannot be NULL.
-        * @param prefix namespace prefix. Optional, can be NULL.
+        * @param node node containing an instance of an OM element,cannot be NULL.
+        * @param env Environment. MUST NOT be NULL.
+        * @param uri namespace uri..
+        * @param prefix namespace prefix. can be NULL.
         * @return pointer to the namespace, if found, else NULL. On error, returns 
         *           NULL and sets the errorno in environment.
         */
-        axis2_om_namespace_t* (AXIS2_CALL *find_namespace)(struct axis2_om_element *om_element,
-                                                           axis2_env_t **env,
-                                                           axis2_om_node_t *node,
-                                                           const axis2_char_t *uri,
-                                                           const axis2_char_t *prefix);
+        axis2_om_namespace_t* (AXIS2_CALL *find_namespace)
+                                        (struct axis2_om_element *om_element,
+                                        axis2_env_t **env,
+                                        axis2_om_node_t *node,
+                                        const axis2_char_t *uri,
+                                        const axis2_char_t *prefix);
       /**
         * Declare a namespace in current element (in the scope of this element ).
         * It checks to see if it is already declared.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param node node containing an instance of an OM element. Mandatory, cannot be NULL.
+        * @param node node containing an instance of an OM element.
+        * @param env Environment. MUST NOT be NULL.
         * @param ns pointer to the namespace struct to be declared
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
-        axis2_status_t (AXIS2_CALL *declare_namespace)(struct axis2_om_element *om_element,
-                                                       axis2_env_t **env,
-                                                       axis2_om_node_t *node,
-                                                       axis2_om_namespace_t * ns);
-
-      /**
-        * find namespaces in the scope of current element
-        * @param environment Environment .MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param element pointer to an om element
-        * @param prefix namespace prefix
-        * @param uri    namespace uri
-        */
-        /*   AXIS2_DECLARE_DATA axis2_om_namespace_t
-            *(AXIS2_CALL *axis2_om_element_ops_find_declared_namespace)
-            (axis2_env_t * environment,
-             struct axis2_om_element * element, const axis2_char_t * uri,
-             const axis2_char_t * prefix);
-             */
-
-      /**
+        axis2_status_t (AXIS2_CALL *declare_namespace)
+                                        (struct axis2_om_element *om_element,
+                                         axis2_env_t **env,
+                                         axis2_om_node_t *node,
+                                         axis2_om_namespace_t * ns);
+       /**
         * Finds a namespace using qname
         * Start to find from the given node and go up the hierarchy.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param node node containing an instance of an OM element. Mandatory, cannot be NULL.
-        * @param qname qname of the namespace to be found. Mandatory, cannot be NULL.
+        * @param om_element om_element contained in node
+        * @param env Environment. MUST NOT be NULL.
+        * @param node node containing an instance of an OM element, cannot be NULL.                                        
+        * @param qname qname of the namespace to be found. cannot be NULL.
         * @return pointer to the namespace, if found, else NULL. On error, returns 
         *           NULL and sets the errorno in environment.
         */
-         axis2_om_namespace_t *(AXIS2_CALL *find_namespace_with_qname)(struct axis2_om_element *om_element,
-                                                                       axis2_env_t **env,
-                                                                       axis2_om_node_t *node,
-                                                                       axis2_qname_t *qname);
+         axis2_om_namespace_t *(AXIS2_CALL *find_namespace_with_qname)
+                                            (struct axis2_om_element *om_element,
+                                             axis2_env_t **env,
+                                             axis2_om_node_t *node,
+                                             axis2_qname_t *qname);
 
       /**
         * Adds an attribute to current element
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param element element to which the attribute is to be added. Mandatory, cannot be NULL.
+        * @param om_element element to which the attribute is to be added.cannot be NULL.
+        * @param env Environment. MUST NOT be NULL.
         * @param attribute attribute to be added.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
@@ -114,8 +103,8 @@
 
       /**
         * Gets (finds) the attribute with the given qname
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param element element whose attribute is to be found. Mandatory, cannot be NULL.
+        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @qname qname qname of the attribute to be found. Mandatory, cannot be NULL.
         * @return a pointer to the attribute with given qname if found, else NULL.
         *           On error, returns NULL and sets the error.
@@ -126,53 +115,62 @@
 
       /**
         * Frees given element 
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param element OM element to be freed.
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
+        * @param env Environment. MUST NOT be NULL.
+         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
          axis2_status_t (AXIS2_CALL *free) (struct axis2_om_element *element,
                                             axis2_env_t **env);
 
       /**
         * Serializes the start part of the given element
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param element element to be serialized.
+        * @param env Environment. MUST NOT be NULL.
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
-        axis2_status_t (AXIS2_CALL *serialize_start_part)(struct axis2_om_element *om_element,
-                                                          axis2_env_t **env,
-                                                          axis2_om_output_t * om_output);
+        axis2_status_t (AXIS2_CALL *serialize_start_part)
+                                                (struct axis2_om_element *om_element,
+                                                 axis2_env_t **env,
+                                                 axis2_om_output_t * om_output);
 
       /**
         * Serializes the end part of the given element. serialize_start_part must 
         *     have been called before calling this method.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param element element to be serialized.
+        * @param om_element element to be serialized.
+        * @param env Environment must not be null.
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
-        axis2_status_t (AXIS2_CALL *serialize_end_part)(struct axis2_om_element *om_element,
-                                                        axis2_env_t **env,
-                                                        axis2_om_output_t * om_output);
-                                                        
+        axis2_status_t (AXIS2_CALL *serialize_end_part)
+                                                    (struct axis2_om_element *om_element,
+                                                     axis2_env_t **env,
+                                                     axis2_om_output_t * om_output);
                                                         
+       /**
+        *   returns the localname of this element
+        */        
         axis2_char_t* (AXIS2_CALL *get_localname)(struct axis2_om_element *om_element,
                                                   axis2_env_t **env);
-
+       /**
+        *   set the localname of this element
+        */
         axis2_status_t (AXIS2_CALL *set_localname)(struct axis2_om_element *om_element,
                                                   axis2_env_t **env,
                                                   const axis2_char_t *localname);
-        
-        axis2_om_namespace_t *(AXIS2_CALL *get_namespace)(struct axis2_om_element *om_element,
-                                                          axis2_env_t **env);
-                                                          
+        /**
+         * returns the namespace of om_element 
+         */
+        axis2_om_namespace_t *(AXIS2_CALL *get_namespace)
+                                                (struct axis2_om_element *om_element,
+                                                 axis2_env_t **env);
+        /**
+        * returns the namespace of om_element 
+        */                                         
         axis2_status_t (AXIS2_CALL *set_namespace)(struct axis2_om_element *om_element,
                                                    axis2_env_t **env,
                                                    axis2_om_namespace_t *ns,
                                                    axis2_om_node_t *node);                                                                                                                                                              
-                                                                                                                  
-
     } axis2_om_element_ops_t;
 
     
@@ -189,11 +187,11 @@
 
   /**
     * Creates an OM element with given local name
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-    * @param parent parent of the element node to be created. Optional, can be NULL.
-    * @param localname local name of the elment. Mandatory, cannot be NULL.
-    * @param ns namespace of the element. Optional, can be NULL.
-    * @param node This is an out parameter. Mandatory, cannot be NULL.
+    * @param env Environment. MUST NOT be NULL.
+    * @param parent parent of the element node to be created. can be NULL.
+    * @param localname local name of the elment. cannot be NULL.
+    * @param ns namespace of the element.  can be NULL.
+    * @param node This is an out parameter. cannot be NULL.
     *                       Returns the node corresponding to the comment created.
     *                       Node type will be set to AXIS2_OM_ELEMENT
     * @return a pointer to the newly created element struct
@@ -207,10 +205,10 @@
 
   /**
     * Creates an OM element with given qname
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-    * @param parent parent of the element node to be created. Optional, can be NULL.
-    * @param qname qname of the elment. Mandatory, cannot be NULL.
-    * @param node This is an out parameter. Mandatory, cannot be NULL.
+    * @param env Environment. MUST NOT be NULL.
+    * @param parent parent of the element node to be created. can be NULL.
+    * @param qname qname of the elment.cannot be NULL.
+    * @param node This is an out parameter. cannot be NULL.
     *                       Returns the node corresponding to the comment created.
     *                       Node type will be set to AXIS2_OM_ELEMENT
     * @return a pointer to the newly created element struct
@@ -241,9 +239,7 @@
 #define AXIS2_OM_ELEMENT_GET_ATTRIBUTE(om_element, env, qname) \
         ((om_element)->ops->get_attribute(om_element, env, qname))
         
-/*#define axis2_om_element_find_declared_namespace(environment,element,uri,prefix) ((element)->ops->axis2_om_element_find_declared_namespace(environment,element,uri,prefix))*/
-/** frees given element */
-
+/** free an om element */
 #define AXIS2_OM_ELEMENT_FREE(om_element, env) \
         ((om_element)->ops->free(om_element, env))
         
@@ -254,16 +250,16 @@
 /** serialize the end part of given element */
 #define AXIS2_OM_ELEMENT_SERIALIZE_END_PART(om_element, env, om_output) \
         ((om_element)->ops->serialize_end_part(om_element, env, om_output))
-
+/** get localname */
 #define AXIS2_OM_ELEMENT_GET_LOCALNAME(om_element, env)\
         ((om_element)->ops->get_localname(om_element,env))
-        
+/** get namespace of this element */        
 #define AXIS2_OM_ELEMENT_GET_NAMESPACE(om_element, env) \
         ((om_element)->ops->get_namespace(om_element, env))
-        
+/** set localname */        
 #define AXIS2_OM_ELEMENT_SET_LOCALNAME(om_element, env, localname) \
         ((om_element)->ops->set_localname(om_element, env))
-        
+/** set namespace */        
 #define AXIS2_OM_ELEMENT_SET_NAMESPACE(om_element, env, ns , node) \
         ((om_element)->ops->set_namespace(om_element, env, ns, node))
         
@@ -275,6 +271,3 @@
 #endif
 
 #endif                          /* AXIS2_OM_ELEMENT_H */
-
-
-

Modified: webservices/axis2/trunk/c/include/axis2_om_namespace.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_namespace.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_namespace.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_namespace.h Sun Nov 20 19:53:26 2005
@@ -19,7 +19,8 @@
 
 /**
  * @file axis2_om_namespace.h
- * @brief defines axis2_om_namespace data structure, used for representing XML namespaces in OM
+ * @brief defines axis2_om_namespace data structure,
+ *        used for representing XML namespaces in OM
  */
 
 #include <axis2_defines.h>
@@ -48,8 +49,8 @@
     {
       /**
         * Frees given OM namespcae
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_namespace namespace to be freed.
+        * @param env Environment. MUST NOT be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
         axis2_status_t (AXIS2_CALL *free) (struct axis2_om_namespace *om_namespace,
@@ -57,43 +58,53 @@
 
       /**
         * Compares two namepsaces
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_namespace1 first namespase to be compared
+        * @param env Environment. MUST NOT be NULL.
         * @param om_namespace2 second namespace to be compared
-        * @return true if the two namespaces are equal, false otherwise	
+        * @return AXIS2_TRUE if the two namespaces are equal,AXIS2_FALSE otherwise
         */
-        axis2_bool_t (AXIS2_CALL *equals) (struct axis2_om_namespace *om_namespace,
-                                           axis2_env_t **env,
-                                           struct axis2_om_namespace *om_namespace1);
+        axis2_bool_t (AXIS2_CALL *equals)(struct axis2_om_namespace *om_namespace,
+                                          axis2_env_t **env,
+                                          struct axis2_om_namespace *om_namespace1);
 
       /**
         * Serializes given namespace 
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_namespace namespace to be serialized.
+        * @param env Environment. MUST NOT be NULL.
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
         axis2_status_t (AXIS2_CALL *serialize)(struct axis2_om_namespace *om_namespace,
                                                axis2_env_t **env,
                                                axis2_om_output_t * om_output);
-                                                       
-                                                       
+       /**   
+        *@param om_namespace
+        *@param env
+        */
         axis2_char_t* (AXIS2_CALL *get_uri)(struct axis2_om_namespace *om_namespace,
                                             axis2_env_t **env);
-
+       /**   
+        *@param om_namespace
+        *@param env
+        */
         axis2_char_t* (AXIS2_CALL *get_prefix)(struct axis2_om_namespace *om_namespace,
                                                axis2_env_t **env);
-        
+        /**   
+        *@param om_namespace
+        *@param env
+        *@param uri 
+        */
         axis2_status_t (AXIS2_CALL *set_uri)(struct axis2_om_namespace *om_namespace,
                                             axis2_env_t **env,
                                             const axis2_char_t *uri);
-        
+        /**   
+        *@param om_namespace
+        *@param env
+        *@param prefix 
+        */
         axis2_status_t (AXIS2_CALL *set_prefix)(struct axis2_om_namespace *om_namespace,
                                                 axis2_env_t **env,
                                                 const axis2_char_t *prefix);
-                                                                                   
-                                                  
-                                                  
 
     } axis2_om_namespace_ops_t;
 
@@ -130,16 +141,16 @@
 /** serializes given namespace */
 #define AXIS2_OM_NAMESPACE_SERIALIZE(om_namespace,env, om_output) \
         ((om_namespace)->ops->serialize(om_namespace, env,om_output))
-        
+/** get prefix */        
 #define AXIS2_OM_NAMESPACE_GET_PREFIX(om_namespace, env) \
         ((om_namespace)->ops->get_prefix(om_namespace, env))
-
+/** get namespace uri */
 #define AXIS2_OM_NAMESPACE_GET_URI(om_namespace, env) \
         ((om_namespace)->ops->get_uri(om_namespace, env))
-
+/** set uri           */
 #define AXIS2_OM_NAMESPACE_SET_URI(om_namespace, env, uri) \
         ((om_namespace)->ops->set_uri(om_namespace, env, uri))
-
+/** set prefix        */
 #define AXIS2_OM_NAMESPACE_SET_PREFIX(om_namespace, env, prefix) \
         ((om_namespace)->ops->set_prefix(om_namesapce, env, prefix))
 
@@ -150,5 +161,3 @@
 #endif
 
 #endif                          /* AXIS2_OM_NAMESPACE */
-
-

Modified: webservices/axis2/trunk/c/include/axis2_om_node.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_node.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_node.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_node.h Sun Nov 20 19:53:26 2005
@@ -79,17 +79,18 @@
     {
        /**
         * Frees an om node and all of its children
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param om_node node to be freed.
+        * @param env Environment. MUST NOT be NULL, .
+
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *free) (struct axis2_om_node *om_node,
                                            axis2_env_t **env);
        /**
         * Adds given node as child to parent
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param parent parent node. Mandatory, cannot be NULL.
-        * @param child child node. Mandatory, cannot be NULL.
+        * @param om_node child node. cannot be NULL.
+        * @param env Environment. MUST NOT be NULL, .
+        * @param child child node. , cannot be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *add_child) (struct axis2_om_node *om_node,
@@ -98,8 +99,8 @@
 
       /**
         * Detaches given node from the parent and reset the links
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param om_node node to be detached. Mandatory, cannot be NULL.
+        * @param om_node node to be detached. , cannot be NULL.
+        * @param env Environment. MUST NOT be NULL, .
         * @return a pointer to detached node, NULL on error.
         */
         struct axis2_om_node *(AXIS2_CALL *detach) (struct axis2_om_node *om_node,
@@ -107,31 +108,33 @@
 
       /**
         * Inserts a sibling node after the given current node
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param current_node node to whom the sibling to be inserted. Mandatory, cannot be NULL.
-        * @param node_to_insert the node to be inserted. Mandatory, cannot be NULL.
+        * @param om_node node to whom the sibling to be inserted. , cannot be NULL.
+        * @param env Environment. MUST NOT be NULL, .
+        * @param node_to_insert the node to be inserted. , cannot be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
-        axis2_status_t (AXIS2_CALL *insert_sibling_after)(struct axis2_om_node *om_node,
-                                                          axis2_env_t **env,
-                                                          struct axis2_om_node * node_to_insert);
+        axis2_status_t (AXIS2_CALL *insert_sibling_after)
+                                        (struct axis2_om_node *om_node,
+                                         axis2_env_t **env,
+                                         struct axis2_om_node * node_to_insert);
 
       /**
         * Inserts a sibling node before the given current node
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param current_node node to whom the sibling to be inserted. Mandatory, cannot be NULL.
-        * @param node_to_insert the node to be inserted. Mandatory, cannot be NULL.
+        * @param om_node node to whom the sibling to be inserted. , cannot be NULL.
+        * @param env Environment. MUST NOT be NULL, .
+        * @param node_to_insert the node to be inserted. , cannot be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
-        axis2_status_t (AXIS2_CALL *insert_sibling_before)(struct axis2_om_node *om_node,
-                                                           axis2_env_t **env,
-                                                           struct axis2_om_node * node_to_insert);
+        axis2_status_t (AXIS2_CALL *insert_sibling_before)
+                                         (struct axis2_om_node *om_node,
+                                          axis2_env_t **env,
+                                          struct axis2_om_node * node_to_insert);
 
       /**
         * Sets a parent node to a given node
-        * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-        * @param child_node child node to whom a parent to be added. Mandatory, cannot be NULL.
-        * @param parent the node that will be set as parent. Mandatory, cannot be NULL.
+        * @param om_node child node to whom a parent to be added. , cannot be NULL.
+        * @param env Environment. MUST NOT be NULL, .
+        * @param parent_node the node that will be set as parent. , cannot be NULL.
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *set_parent) (struct axis2_om_node *om_node,
@@ -142,77 +145,83 @@
        /**
         * Serializes the given node. This operation makes the node go through its children and 
         * serialize them in order.
-        * @param env Environment .MUST NOT be NULL, if NULL behaviour is undefined.    
-        * @param node node to be serialized. Mandatory cannot be NULL.
+        * @param om_node node to be serialized.  cannot be NULL.
+        * @param env Environment .MUST NOT be NULL.    
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *serialize) (struct axis2_om_node * om_node, axis2_env_t **env,
                                     struct axis2_om_output *om_output);
-                                                
-        struct axis2_om_node* (AXIS2_CALL *get_parent)(struct axis2_om_node *om_node,
-                                                    axis2_env_t **env);
+        /** getter setter methods *************************************/                                                
+        struct axis2_om_node* (AXIS2_CALL *get_parent)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env);
 
-        struct axis2_om_node* (AXIS2_CALL *get_first_child)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env);
+        struct axis2_om_node* (AXIS2_CALL *get_first_child)
+                                                    (struct axis2_om_node *om_node,
+                                                    axis2_env_t **env);
                     
-        struct axis2_om_node* (AXIS2_CALL *get_last_child)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env);
-
-        struct axis2_om_node* (AXIS2_CALL *get_previous_sibling)(struct axis2_om_node *om_node,
-                                                            axis2_env_t **env);
-
-        struct axis2_om_node* (AXIS2_CALL *get_next_sibling)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env);
-
-        axis2_om_types_t (AXIS2_CALL *get_node_type)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env);
+        struct axis2_om_node* (AXIS2_CALL *get_last_child)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env);
+
+        struct axis2_om_node* (AXIS2_CALL *get_previous_sibling)
+                                            (struct axis2_om_node *om_node,
+                                            axis2_env_t **env);
+
+        struct axis2_om_node* (AXIS2_CALL *get_next_sibling)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env);
+
+        axis2_om_types_t (AXIS2_CALL *get_node_type)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env);
                                                 
         void* (AXIS2_CALL *get_data_element)(struct axis2_om_node *om_node,
-                                                axis2_env_t **env);    
+                                             axis2_env_t **env);    
                                                 
-        axis2_bool_t (AXIS2_CALL *get_build_status)(struct axis2_om_node *om_node,
-                                                    axis2_env_t **env);                            
-
-        axis2_status_t (AXIS2_CALL *set_first_child)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env,
-                                                        struct axis2_om_node *first_child);
+        axis2_bool_t (AXIS2_CALL *get_build_status)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env);                            
+
+        axis2_status_t (AXIS2_CALL *set_first_child)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             struct axis2_om_node *first_child);
                     
-        axis2_status_t (AXIS2_CALL *set_last_child)(struct axis2_om_node *om_node,
-                                                    axis2_env_t **env,
-                                                    struct axis2_om_node *last_child);
-        axis2_status_t (AXIS2_CALL *set_next_sibling)(struct axis2_om_node *om_node,
-                                                        axis2_env_t **env,
-                                                        struct axis2_om_node *last_sibling);
+        axis2_status_t (AXIS2_CALL *set_last_child)
+                                             (struct axis2_om_node *om_node,
+                                              axis2_env_t **env,
+                                              struct axis2_om_node *last_child);
+                                                  
+        axis2_status_t (AXIS2_CALL *set_next_sibling)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             struct axis2_om_node *last_sibling);
         
-        axis2_status_t (AXIS2_CALL *set_previous_sibling)(struct axis2_om_node *om_node,
-                                                            axis2_env_t **env,
-                                                            struct axis2_om_node *prev_sibling);
+        axis2_status_t (AXIS2_CALL *set_previous_sibling)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             struct axis2_om_node *prev_sibling);
         
-        axis2_status_t (AXIS2_CALL *set_node_type)(struct axis2_om_node *om_node,
-                                                axis2_env_t **env,
-                                                axis2_om_types_t type);
+        axis2_status_t (AXIS2_CALL *set_node_type)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             axis2_om_types_t type);
         
-        axis2_status_t (AXIS2_CALL *set_data_element)(struct axis2_om_node *om_node,
-                                                    axis2_env_t **env,
-                                                    void* data_element);
-        axis2_status_t (AXIS2_CALL *set_build_status)(struct axis2_om_node *om_node,
-                                                    axis2_env_t **env,
-                                                    axis2_bool_t done);
+        axis2_status_t (AXIS2_CALL *set_data_element)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             void* data_element);
+        axis2_status_t (AXIS2_CALL *set_build_status)
+                                            (struct axis2_om_node *om_node,
+                                             axis2_env_t **env,
+                                             axis2_bool_t done);
     } axis2_om_node_ops_t;
 
 
 /**
 * This is the structure that defines a node in om tree 
-* @param parent   - parent node if one is available
-* @param parser   - carries a pointer to the XML_PullParser 
-* @param element_type - the type of the element one of omtypes
-* @param data_element  - stores the structs created for storing xml elements
-*						e.g axis2_om_element_t axis2_om_text_t  
-*
-* we keep pointers parent , previous sibling , next sibling , 
-* first child and last child for constructing and navigating the tree
-*
 */
 
     typedef struct axis2_om_node
@@ -224,7 +233,7 @@
 
   /**
     * Creates a node struct.
-    * @param env Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+    * @param env Environment. MUST NOT be NULL, .
     * @return a pointer to newly created node struct. NULL on error. 
     */
 AXIS2_DECLARE(axis2_om_node_t *) axis2_om_node_create (axis2_env_t **env);
@@ -241,43 +250,43 @@
 /** inserts a sibling after the given node */
 
 #define AXIS2_OM_NODE_INSERT_SIBLING_AFTER(om_node,env,node_to_insert) \
-        ((current_node)->ops->insert_sibling_after(om_node,env,node_to_insert))
+        ((om_node)->ops->insert_sibling_after(om_node,env,node_to_insert))
 /** inserts a sibling before the given node */
 #define AXIS2_OM_NODE_INSERT_SIBLING_BEFORE(om_node,env,node_to_insert) \
-        ((current_node)->ops->insert_sibling_before(om_node,env,node_to_insert))
+        ((om_node)->ops->insert_sibling_before(om_node,env,node_to_insert))
    
 /** sets the parent of the given node */
 #define AXIS2_OM_NODE_SET_PARENT(om_node,env,parent_node) \
         ((om_node)->ops->set_parent(om_node,env,parent_node))
-
+/** serialize an om_node and all its children */
 #define AXIS2_OM_NODE_SERIALIZE(om_node,env, om_output) \
         ((om_node)->ops->serialize(om_node,env,om_output))
-   
+/** returns parent of this om_node */   
 #define AXIS2_OM_NODE_GET_PARENT(om_node,env) \
         ((om_node)->ops->get_parent(om_node,env))
-
+/** get firet child of this om_node  */
 #define AXIS2_OM_NODE_GET_FIRST_CHILD(om_node,env) \
         ((om_node)->ops->get_first_child(om_node,env))
-   
+/**get last child  */  
 #define AXIS2_OM_NODE_GET_LAST_CHILD(om_node,env) \
         ((om_node)->ops->get_last_child(om_node,env))
-   
+/** get next sibling */  
 #define AXIS2_OM_NODE_GET_NEXT_SIBLING(om_node,env) \
         ((om_node)->ops->get_next_sibling(om_node,env))
-  
+/** get previous sibling */
 #define AXIS2_OM_NODE_GET_PREVIOUS_SIBLING(om_node,env) \
         ((om_node)->ops->get_previous_sibling(om_node,env))
-
+/** get build status */
 #define AXIS2_OM_NODE_GET_BUILD_STATUS(om_node,env) \
         ((om_node)->ops->get_build_status(om_node,env))
-
+/** get data element of this node can be om_element om_text etc */
 #define AXIS2_OM_NODE_GET_DATA_ELEMENT(om_node,env) \
         ((om_node)->ops->get_data_element(om_node,env))
         
-
+/** node type one of om_node_types */
 #define AXIS2_OM_NODE_GET_NODE_TYPE(om_node,env) \
         ((om_node)->ops->get_node_type(om_node,env))       
-
+/*** setter methods */
 #define AXIS2_OM_NODE_SET_LAST_CHILD(om_node,env,last_child) \
         ((om_node)->ops->set_last_child(om_node,env,last_child))
 

Modified: webservices/axis2/trunk/c/include/axis2_om_output.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_output.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_output.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_output.h Sun Nov 20 19:53:26 2005
@@ -23,6 +23,7 @@
  */
 
 #include <axis2_defines.h>
+#include <axis2.h>
 #include <axis2_env.h>
 #include <axis2_om_node.h>
 #include <axis2_xml_writer.h>
@@ -64,21 +65,19 @@
     
   /**
     * creates OM output struct 
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
-    * @param xml_writer XML writer. Optional, can be NULL. If NULL default xml writer
-    *           (guththila writer ) will be created with stdout as the output stream
-	* @param writer_env writer envioronment. Optional, can be NULL.
+    * @param env Environment. MUST NOT be NULL, .
+    * @param xml_writer XML writer. 
     * @return a pointer to newly created output struct.
     */
 
     AXIS2_DECLARE(axis2_om_output_t*) 
-    axis2_om_output_create (axis2_env_t **environment, axis2_xml_writer_t *xml_writer);
+    axis2_om_output_create (axis2_env_t **env, axis2_xml_writer_t *xml_writer);
 
   /**
     *  Performs xml writing.
     *  Accepts variable number of args depending on the on OM type to be serialized
-    *  @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
     *  @param om_output Output struct to be used 
+    *  @param env Environment. MUST NOT be NULL, 
     *  @param type one of the OM types
     *  @param no_of_args number of arguments passed in the variable parameter list
     *  @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
@@ -88,6 +87,17 @@
     axis2_om_output_write (axis2_om_output_t * om_output, axis2_env_t **env,
                            axis2_om_types_t type,
                            int no_of_args, ...);
+   /**
+    * free om_output 
+    *@param om_output om_output struct
+    *@param env environment
+    *@return status code AXIS2_SUCCESS on success, AXIS2_FAILURE otherwise 
+    */
+    
+                
+    AXIS2_DECLARE(axis2_status_t)
+    axis2_om_output_free(axis2_om_output_t *om_output,
+                         axis2_env_t **env);    
 
 /** @} */
 

Modified: webservices/axis2/trunk/c/include/axis2_om_processing_instruction.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_processing_instruction.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_processing_instruction.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_processing_instruction.h Sun Nov 20 19:53:26 2005
@@ -23,6 +23,7 @@
  */
 
 #include <axis2_om_node.h>
+#include <axis2_om_output.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -48,29 +49,55 @@
     {
         /**
          * Frees an instance of axis2_om_processing_instruction
-         * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
          * @param om_pi processing instruction to be freed.
+         * @param env Environment. MUST NOT be NULL, .
          * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
          */
-        axis2_status_t 
-        (AXIS2_CALL *free)(struct axis2_om_processing_instruction * om_pi,
-                           axis2_env_t **env);
-        axis2_status_t 
-        (AXIS2_CALL *set_value)(struct axis2_om_processing_instruction *om_pi,
+        axis2_status_t (AXIS2_CALL *free)
+                            (struct axis2_om_processing_instruction * om_pi,
+                             axis2_env_t **env);
+        /**
+         * set processing instruction data
+         *@param om_pi
+         *@param env        
+         *@param value 
+         */
+         
+        axis2_status_t (AXIS2_CALL *set_value)
+                                (struct axis2_om_processing_instruction *om_pi,
                                 axis2_env_t **env,
                                 const axis2_char_t* value);
-        axis2_status_t 
-        (AXIS2_CALL *set_target)(struct axis2_om_processing_instruction *om_pi,
+        /**
+         * set processing instruction target
+         *@param om_pi
+         *@param env        
+         *@param target
+         */
+        
+        axis2_status_t (AXIS2_CALL *set_target)
+                                (struct axis2_om_processing_instruction *om_pi,
                                 axis2_env_t **env,
                                 const axis2_char_t* target);
-        axis2_char_t*
-        (AXIS2_CALL *get_target)(struct axis2_om_processing_instruction *om_pi,
+        /**
+         * get PI target
+         */
+        axis2_char_t* (AXIS2_CALL *get_target)
+                                (struct axis2_om_processing_instruction *om_pi,
                                  axis2_env_t **env);
-        axis2_char_t*
-        (AXIS2_CALL *get_value)(struct axis2_om_processing_instruction *om_pi,
-                                axis2_env_t **env);                                                                                                                           
+        /**
+         *  get PI value 
+         */
+        axis2_char_t* (AXIS2_CALL *get_value)
+                                (struct axis2_om_processing_instruction *om_pi,
+                                 axis2_env_t **env);                                                                                                                           
                            
-                                          
+        /**
+         *  serialize function 
+         */
+        axis2_status_t (AXIS2_CALL *serialize)
+                                (struct axis2_om_processing_instruction *om_pi,
+                                 axis2_env_t **env, axis2_om_output_t *om_output);
+                                    
                                           
     } axis2_om_processing_instruction_ops_t;
 
@@ -87,7 +114,7 @@
 
   /**
     * Creates a processing instruction 
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+    * @param environment Environment. MUST NOT be NULL, .
     * @param parent parent of the element node to be created. Optional, can be NULL.
     * @param target target of the processing instruction. Mandatory, cannot be NULL.
     * @param value value of the processing instruction. Mandatory, cannot be NULL.
@@ -104,18 +131,24 @@
                                                 axis2_om_node_t ** node);
 
 /** frees given processing instruction */
-#define AXIS2_OM_PROCESSING_INSTRUCTION_FREE(pi,env) \
+#define AXIS2_OM_PROCESSING_INSTRUCTION_FREE(pi, env) \
         ((pi)->ops->free(pi, env))
-#define AXIS2_OM_PROCESSING_INSTRUCION_SET_VALUE(pi,env,value) \
+        
+#define AXIS2_OM_PROCESSING_INSTRUCION_SET_VALUE(pi, env, value) \
         ((pi)->ops->set_value(pi,env,value))
-#define AXIS2_OM_PROCESSING_INSTRUCTION_GET_VALUE(pi,env) \
-        ((pi)->ops->get_value(pi,env))        
-#define AXIS2_OM_PROCESSING_INSTRUCION_SET_TARGET(pi,env,value) \
-        ((pi)->ops->set_target(pi,env,value))
-#define AXIS2_OM_PROCESSING_INSTRUCTION_GET_TARGET(pi,env) \
-        ((pi)->ops->get_target(pi,env))
+        
+#define AXIS2_OM_PROCESSING_INSTRUCTION_GET_VALUE(pi, env) \
+        ((pi)->ops->get_value(pi, env))        
+        
+#define AXIS2_OM_PROCESSING_INSTRUCION_SET_TARGET(pi, env, value) \
+        ((pi)->ops->set_target(pi, env, value))
+        
+#define AXIS2_OM_PROCESSING_INSTRUCTION_GET_TARGET(pi, env) \
+        ((pi)->ops->get_target(pi, env))
+
 
-#define AXIS2        
+#define AXIS2_OM_PROCESSING_INSTRUCTION_SERIALIZE(pi, env, om_output) \
+        ((pi)->ops->serialize(pi, env, om_output))
 
 /** @} */
 #ifdef __cplusplus
@@ -123,6 +156,3 @@
 #endif
 
 #endif                          /* AXIS2_OM_PI_H */
-
-
-

Modified: webservices/axis2/trunk/c/include/axis2_om_stax_builder.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_stax_builder.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_stax_builder.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_stax_builder.h Sun Nov 20 19:53:26 2005
@@ -49,7 +49,7 @@
     {
       /**
         * Builds the next node from stream. Moves pull parser forward and reacts to events.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+        * @param environment Environment. MUST NOT be NULL, .
         * @param builder pointer to stax builder struct to be used
         * @return a pointer to the next node, or NULL if there are no more nodes.
         *           On erros sets the error and returns NULL.
@@ -59,7 +59,7 @@
 
       /**
         * Discards the element that is being built currently.
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+        * @param environment Environment. MUST NOT be NULL, .
         * @param builder pointer to stax builder struct to be used
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
@@ -102,11 +102,21 @@
 
   /**
     * creates an stax builder
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+    * @param environment Environment. MUST NOT be NULL, .
     * @return a pointer to the newly created builder struct. 
     */
     AXIS2_DECLARE(axis2_om_stax_builder_t *)
-    axis2_om_stax_builder_create (axis2_env_t **env,void* stream);
+    axis2_om_stax_builder_create_for_file (axis2_env_t **env,char* filename);
+
+    /**
+    * creates an stax builder
+    * @param environment Environment. MUST NOT be NULL, .
+    * @return a pointer to the newly created builder struct. 
+    */
+    AXIS2_DECLARE(axis2_om_stax_builder_t *)
+    axis2_om_stax_builder_create_for_memory (axis2_env_t **env,
+                                             int (*read_input_callback)(char *buffer,int size),
+                                             void (*close_input_callback)(void));
 
 /** builds next node */
 #define AXIS2_OM_STAX_BUILDER_NEXT(builder,env) \

Modified: webservices/axis2/trunk/c/include/axis2_om_text.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_text.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_om_text.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_text.h Sun Nov 20 19:53:26 2005
@@ -48,7 +48,7 @@
     {
       /**
         * Free an axis2_om_text struct
-        * @param environment environment. Mandatory, MUST NOT be NULL, if NULL behaviour is undefined.
+        * @param environment environment.  MUST NOT be NULL, .
         * @param om_text pointer to om text struct to be freed
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
@@ -57,7 +57,7 @@
 
       /**
         * Serialize operation
-        * @param environment environment. Mandatory, MUST NOT be NULL, if NULL behaviour is undefined.
+        * @param environment environment.  MUST NOT be NULL, .
         * @param om_text pointer to om text struct to be serialized
         * @param om_output OM output handler to be used in serializing
         * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
@@ -90,11 +90,11 @@
 
   /**
     * Creates a new text struct
-    * @param environment Environment. MUST  NOT be NULL, if NULL behaviour is undefined.
+    * @param environment Environment. MUST  NOT be NULL, .
     * @param parent parent of the new node. Optinal, can be NULL. 
     *          The parent element must be of type AXIS2_OM_ELEMENT
     * @param value Text value. Optinal, can be NULL.
-    * @param comment_node This is an out parameter. Mandatory, cannot be NULL.
+    * @param comment_node This is an out parameter.  cannot be NULL.
     *                       Returns the node corresponding to the text struct created.
     *                       Node type will be set to AXIS2_OM_TEXT    
     * @return pointer to newly created text struct 

Added: webservices/axis2/trunk/c/modules/test/om/src/axis.xml
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/test/om/src/axis.xml?rev=345821&view=auto
==============================================================================
--- webservices/axis2/trunk/c/modules/test/om/src/axis.xml (added)
+++ webservices/axis2/trunk/c/modules/test/om/src/axis.xml Sun Nov 20 19:53:26 2005
@@ -0,0 +1,25 @@
+<?xml version="1.0"?>
+
+<root>
+
+  <a>
+    <a.1/>
+    <a.2/>
+    <a.3/>
+    <a.4/>
+    <a.5/>
+  </a>
+
+  <b>
+    <b.1/>
+    <b.2/>
+    <b.3/>
+    <b.4/>
+    <b.5/>
+    <b.6/>
+    <b.7/>
+    <b.8/>
+    <b.9/>
+  </b>
+
+</root>

Added: webservices/axis2/trunk/c/modules/test/om/src/basic.xml
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/test/om/src/basic.xml?rev=345821&view=auto
==============================================================================
--- webservices/axis2/trunk/c/modules/test/om/src/basic.xml (added)
+++ webservices/axis2/trunk/c/modules/test/om/src/basic.xml Sun Nov 20 19:53:26 2005
@@ -0,0 +1,11 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+
+<foo>
+    <bar>
+        <baz/>
+        <cheese/>
+        <baz/>
+        <cheese/>
+        <baz/>
+    </bar>
+</foo>

Added: webservices/axis2/trunk/c/modules/test/om/src/basicupdate.xml
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/test/om/src/basicupdate.xml?rev=345821&view=auto
==============================================================================
--- webservices/axis2/trunk/c/modules/test/om/src/basicupdate.xml (added)
+++ webservices/axis2/trunk/c/modules/test/om/src/basicupdate.xml Sun Nov 20 19:53:26 2005
@@ -0,0 +1,47 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+
+<xu:modifications xmlns:xu="http://www.xmldb.org/xupdate">
+
+  <xu:append select="/foo/bar/cheese[1]">
+    Goudse kaas
+    <edam type="jong belegen">Rond</edam>
+  </xu:append>
+
+  <xu:remove select="/foo/bar/baz[2]"/>
+
+  <xu:if test="/foo">
+    <xu:insert-before select="/foo/bar/baz[2]">
+      <cheese>More cheese!</cheese>
+    </xu:insert-before>
+  </xu:if>
+
+  <xu:insert-before select="/foo/bar/baz[2]">
+    <cheese>Even more cheese!</cheese>
+  </xu:insert-before>
+
+  <xu:if test="/bar">
+    <xu:insert-before select="/foo/bar/baz[2]">
+      <sausages>No sausages today</sausages>
+    </xu:insert-before>
+  </xu:if>
+
+  <xu:variable
+    xmlns:private="http://www.jaxen.org/private"
+    name="private:twice">
+    <cracker/>
+    <!-- champagne -->
+    <?oisters with a bit of lemon?>
+  </xu:variable>
+
+  <xu:variable name="twice" select="'Twice'"/>
+  
+  <xu:insert-after
+    select="/foo/bar"
+    xmlns:private="http://www.jaxen.org/private"
+    >
+    <xu:value-of select="$private:twice"/>
+    <xu:value-of select="$private:twice"/>
+    <xu:value-of select="$twice"/>
+  </xu:insert-after>
+
+</xu:modifications>
--- webservices/axis2/trunk/c/include/axis2_om_comment.h (original)
+++ webservices/axis2/trunk/c/include/axis2_om_comment.h Sun Nov 20 19:53:26 2005
@@ -23,6 +23,7 @@
  */
 
 #include <axis2_om_node.h>
+#include <axis2_om_output.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -47,19 +48,32 @@
     {
       /**
         * Free a axis2_comment struct
-        * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
         * @param comment pointer to axis2_commnet struct to be freed
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE.
+        * @param environment Environment. MUST NOT be NULL.
+        * @return satus of the operation. 
+        *                AXIS2_SUCCESS on success else AXIS2_FAILURE.
         */
         axis2_status_t (AXIS2_CALL *free) (struct axis2_om_comment *om_comment,
                                            axis2_env_t **env);
-
+       /**
+        * get the comment data 
+        *
+        */
+               
         axis2_char_t* (AXIS2_CALL *get_value)(struct axis2_om_comment *om_comment,
-                                               axis2_env_t **env);
-
+                                              axis2_env_t **env);
+       /**
+        * set comment data
+        */
         axis2_status_t (AXIS2_CALL *set_value)(struct axis2_om_comment *om_comment,
                                               axis2_env_t **env,
                                               const axis2_char_t* value);
+        /**
+         *  serialize function
+         */
+        axis2_status_t (AXIS2_CALL *serialize)(struct axis2_om_comment *om_comment,
+                                               axis2_env_t **env,
+                                               axis2_om_output_t *om_output);
                                                                                             
                                               
     } axis2_om_comment_ops_t;
@@ -77,28 +91,32 @@
 
   /**
     * Creates a comment struct
     * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
     * @param value comment text
-    * @param comment_node This is an out parameter. Mandatory, cannot be NULL.
-    *                       Returns the node corresponding to the comment created.
-    *                       Node type will be set to AXIS2_OM_COMMENT
+    * @param node This is an out parameter.cannot be NULL.
+    *        Returns the node corresponding to the comment created.
+    *        Node type will be set to AXIS2_OM_COMMENT
     * @return a pointer to the newly created comment struct
     */
     AXIS2_DECLARE(axis2_om_comment_t *) 
     axis2_om_comment_create (axis2_env_t **env,
+                             axis2_om_node_t *parent,
                              const axis2_char_t *value,
-                             axis2_om_node_t **comment_node);
+                             axis2_om_node_t **node);
 
 /** free given comment */
 #define AXIS2_OM_COMMENT_FREE(om_comment, env) \
         ((om_comment)->ops->free(om_comment, env))
-
+/** get comment value */
 #define AXIS2_OM_COMMENT_GET_VALUE(om_comment, env) \
         ((om_comment)->ops->get_value(om_comment, env))
-        
+/** set comment value */        
 #define AXIS2_OM_COMMENT_SET_VALUE(om_comment, env, value) \
         ((om_comment)->ops->set_value(om_comment, env, value))
-                        
+
+#define AXIS2_OM_COMMENT_SERIALIZE(om_comment, env, om_output) \
+        ((om_comment)->ops->serialize(om_comment, env, om_output))
 
 /** @} */
 
@@ -77,28 +91,32 @@
   /**
     * Creates a comment struct
-    * @param environment Environment. MUST NOT be NULL, if NULL behaviour is undefined.
+    * @param environment Environment. MUST NOT be NULL,
+    * @param parent This is the parent node of the comment is any can be null.
     * @param value comment text

Modified: webservices/axis2/trunk/c/include/axis2_om_doctype.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_om_doctype.h?rev=345821&r1=345820&r2=345821&view=diff
==============================================================================